@@ -1,6 +1,6 @@
 __all__ = ('LoanPoint', 'LoanObjectPoint', 'ClosedLoanPoint', 'ClosedLoanObjectPoint', 'LoanPaymentPoint',
            'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint', 'RestructureLoanPoint', 'ValidateLoanPoint',
-           'PublicPaymentPoint',
+           'PublicPaymentPoint', 'CallBackPaymentPoint',
            )
 
 from typing import OrderedDict, Union
@@ -191,7 +191,7 @@ class PublicPaymentCreateContract(Contract):
 
 class CallBackPaymentCreateContract(Contract):
     amount = serializers.DecimalField(max_digits=16, decimal_places=0)
-    bank_card_payment_id = serializers.IntegerField()
+    payment_id = serializers.IntegerField()
 
 
 class CallBackPaymentResponseContract(Contract):
@@ -330,5 +330,3 @@ class CallBackPaymentPoint(CreatePointMixin, ResponseMixin, ContractPoint):
     _point_id = CallBackPaymentID()
     _create_contract = CallBackPaymentCreateContract
     _response_contract = CallBackPaymentResponseContract
-
-
