@@ -1,4 +1,4 @@
-__all__ = ('BankCardPaymentPoint', 'PublicBankCardPaymentPoint', 'PaymentInvoicePoint')
+__all__ = ('BankCardPaymentPoint', 'PublicBankCardPaymentPoint', 'PaymentInvoicePoint', 'PublicTransaction3DSPoint')
 
 from expressmoney.api import *
 
@@ -19,12 +19,19 @@ class PaymentInvoiceCreateContract(Contract):
     description = serializers.CharField(max_length=512)
 
 
+class PublicTransaction3DSCreateContract(Contract):
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1)
+    ip = serializers.IPAddressField(min_value=1)
+    cryptogram = serializers.CharField(max_length=2048)
+    loan_id = serializers.IntegerField(min_value=1)
+    user_id = serializers.IntegerField(min_value=1)
+
+
 class PaymentInvoiceResponseContract(Contract):
     id = serializers.IntegerField(min_value=1)
     url = serializers.CharField(max_length=512)
 
 
-
 class BankCardPaymentResponseContract(Contract):
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
@@ -36,17 +43,14 @@ class BankCardPaymentReadContract(BankCardPaymentCreateContract):
 
 
 class PublicBankCardPaymentCreateContract(Contract):
-    amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1)
-    ip = serializers.CharField(max_length=32)
-    withdraw = serializers.BooleanField()
-    order_id = serializers.IntegerField()
-    order_type = serializers.CharField(max_length=128)
-    cryptogram = serializers.CharField(max_length=2048)
+    md = serializers.CharField(max_length=8192)
+    pa_res = serializers.CharField(max_length=8192)
 
 
-class PublicBankCardPaymentResponseContract(Contract):
-    id = serializers.IntegerField(min_value=1)
-    url = serializers.CharField(max_length=512)
+class PublicTransaction3DSResponse(Contract):
+    acs_url = serializers.URLField(required=False)
+    pa_req = serializers.CharField(required=False)
+    md = serializers.CharField(required=False)
 
 
 class BankCardPaymentID(ID):
@@ -67,6 +71,12 @@ class PublicBankCardPaymentID(ID):
     _view_set = 'bank_card_public_payment'
 
 
+class PublicTransaction3DSID(ID):
+    _service = SERVICE
+    _app = 'payments'
+    _view_set = 'public_transaction_3ds'
+
+
 class BankCardPaymentPoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
     _point_id = BankCardPaymentID()
     _create_contract = BankCardPaymentCreateContract
@@ -80,7 +90,12 @@ class PaymentInvoicePoint(CreatePointMixin, ResponseMixin, ContractPoint):
     _response_contract = PaymentInvoiceResponseContract
 
 
-class PublicBankCardPaymentPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+class PublicBankCardPaymentPoint(CreatePointMixin, ContractPoint):
     _point_id = PublicBankCardPaymentID()
     _create_contract = PublicBankCardPaymentCreateContract
-    _response_contract = PublicBankCardPaymentResponseContract
+
+
+class PublicTransaction3DSPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+    _point_id = PublicTransaction3DSID()
+    _create_contract = PublicTransaction3DSCreateContract
+    _response_contract = PublicTransaction3DSResponse
