@@ -1,6 +1,6 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
            'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'UnlimitedSetCreditScorePoint', 'DocumentPoint',
-           'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint', 'SetCreditScorePoint')
+           'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint', 'SetCreditScorePoint', 'UpdateClientAddressPoint')
 
 from expressmoney.api import *
 
@@ -24,9 +24,9 @@ class ProfileUpdateContract(Contract):
     last_name = serializers.CharField(max_length=32)
     middle_name = serializers.CharField(max_length=32)
     birth_date = serializers.DateField()
-    state = serializers.CharField(max_length=32, allow_blank=True)
-    city = serializers.CharField(max_length=32, allow_blank=True)
-    street = serializers.CharField(max_length=32, allow_blank=True)
+    state = serializers.CharField(max_length=256, allow_blank=True)
+    city = serializers.CharField(max_length=256, allow_blank=True)
+    street = serializers.CharField(max_length=256, allow_blank=True)
     street_house = serializers.CharField(max_length=8, allow_blank=True)
     street_apartment = serializers.CharField(max_length=8, allow_blank=True)
     address = serializers.CharField(max_length=256, allow_blank=True)
@@ -47,9 +47,9 @@ class ProfileCreateContract(ProfileUpdateContract):
     )
     # Address
     postal_code = serializers.CharField(max_length=16, allow_blank=True)
-    state = serializers.CharField(max_length=32, allow_blank=True)
-    city = serializers.CharField(max_length=32, allow_blank=True)
-    street = serializers.CharField(max_length=32, allow_blank=True)
+    state = serializers.CharField(max_length=256, allow_blank=True)
+    city = serializers.CharField(max_length=256, allow_blank=True)
+    street = serializers.CharField(max_length=256, allow_blank=True)
     street_house = serializers.CharField(max_length=8, allow_blank=True)
     street_building = serializers.CharField(max_length=4, allow_blank=True)
     street_lane = serializers.CharField(max_length=16, allow_blank=True)
@@ -89,9 +89,9 @@ class RussianProfileUpdateContract(ProfileUpdateContract):
 
 class RussianProfileUpdateAddressContract(Contract):
     postal_code = serializers.CharField(max_length=16)
-    state = serializers.CharField(max_length=32)
-    city = serializers.CharField(max_length=32)
-    street = serializers.CharField(max_length=32)
+    state = serializers.CharField(max_length=256)
+    city = serializers.CharField(max_length=256)
+    street = serializers.CharField(max_length=256)
     street_house = serializers.CharField(max_length=8)
     street_apartment = serializers.CharField(max_length=8, allow_blank=True)
     address = serializers.CharField(max_length=256)
@@ -177,7 +177,7 @@ class RussianProfileID(ID):
 class RussianProfileUpdateAddressID(ID):
     _service = SERVICE
     _app = 'profiles'
-    _view_set = 'russian_profile_update_address'
+    _view_set = 'update_client_address'
 
 
 class UserProfileID(ID):
@@ -267,9 +267,9 @@ class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractOb
     _update_contract = RussianProfileUpdateContract
 
 
-class RussianProfileObjectUpdateAddressPoint(UpdatePointMixin, ContractObjectPoint):
+class UpdateClientAddressPoint(CreatePointMixin, ContractPoint):
     _point_id = RussianProfileUpdateAddressID()
-    _update_contract = RussianProfileUpdateAddressContract
+    _create_contract = RussianProfileUpdateAddressContract
 
 
 class ProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
